==> lifestyle-pimcore-plugin-assign-product-images-1.5.2-2a73b6.zip: src/Lifestyle/Pimcore/AssignProductImagesBundle/EventListener/AddAssetListener.php <==
<?php
/**
 * Lifestyle Webconsulting GmbH
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @author      r.stetter
 * @copyright   2019 Lifestyle Webconsulting GmbH
 * @link        http://www.life-style.de
 */

namespace Lifestyle\Pimcore\AssignProductImagesBundle\EventListener;

use Lifestyle\Pimcore\AssignProductImagesBundle\Configuration\ActiveConfig;
use Lifestyle\Pimcore\AssignProductImagesBundle\Configuration\PictureTypesList;
use Lifestyle\Pimcore\AssignProductImagesBundle\Events\AssignProductImagesEvents;
use Lifestyle\Pimcore\AssignProductImagesBundle\Model\AssetInfo;
use Lifestyle\Pimcore\AssignProductImagesBundle\Services\AssetTypeHandler\AssetTypeHandlerFactory;
use Pimcore\Event\Model\AssetEvent;
use Pimcore\Model\Asset;
use Pimcore\Model\Asset\Image;
use Pimcore\Model\Asset\Unknown;
use Pimcore\Model\Factory as ModelFactory;
use Pimcore\Tests\Helper\Model;
use Symfony\Component\EventDispatcher\EventDispatcher;

/**
 * Class AddAssetListener
 *
 * @package Lifestyle\Pimcore\AssignProductImagesBundle\EventListener
 */
class AddAssetListener
{
    /**
     * @var AssetTypeHandlerFactory
     */
    protected $assetTypeHandlerFactory;
    /**
     * @var EventDispatcher
     */
    protected $eventDispatcher;
    /**
     * @var PictureTypesList
     */
    protected $pictureTypesList;
    /**
     * @var ModelFactory;
     */
    protected $modelFactory;
    /**
     * @var bool
     */
    protected $active = false;

    /**
     * AddAssetListener constructor.
     *
     * @param AssetTypeHandlerFactory $assetTypeHandlerFactory
     * @param EventDispatcher         $eventDispatcher
     * @param PictureTypesList        $pictureTypesList
     * @param ModelFactory            $modelFactory
     * @param ActiveConfig            $activeConfig
     */
    public function __construct(
        AssetTypeHandlerFactory $assetTypeHandlerFactory,
        EventDispatcher $eventDispatcher,
        PictureTypesList $pictureTypesList,
        ModelFactory $modelFactory,
        ActiveConfig $activeConfig
    ) {
        $this->assetTypeHandlerFactory = $assetTypeHandlerFactory;
        $this->eventDispatcher = $eventDispatcher;
        $this->pictureTypesList = $pictureTypesList;
        $this->modelFactory = $modelFactory;
        $this->active = $activeConfig->isActive();
    }

    /**
     * @param AssetEvent $assetEvent
     */
    public function onAssetUpdated(AssetEvent $assetEvent)
    {
        if (false === $this->active) {
            return;
        }

        $assetInfo = new AssetInfo($assetEvent->getAsset());

        if ($this->pictureTypesList->hasPictureType($assetInfo->getPictureType())
            && ($assetEvent->getAsset() instanceof Image || $assetEvent->getAsset() instanceof Unknown)
        ) {
            $pictureTypeConfig = $this->pictureTypesList->getPictureTypeConfig($assetInfo->getPictureType());

            if (false === stripos($assetEvent->getAsset()->getFullPath(), '/' . $pictureTypeConfig->getProcessingPath())) {
                $success = $this->assetTypeHandlerFactory->getByType($pictureTypeConfig->getType())->process(
                    $assetEvent,
                    $pictureTypeConfig
                );

                if (true === $success) {
                    // dispatch post assign event
                    $this->eventDispatcher->dispatch(AssignProductImagesEvents::POST_ASSIGN, $assetEvent);
                }
            }
        }
    }

    /**
     * @param AssetEvent $assetEvent
     */
    public function onBeforeAssetUpdated(AssetEvent $assetEvent)
    {
        if (false === $this->active) {
            return;
        }

        $assetInfo = new AssetInfo($assetEvent->getAsset());

        if ($this->pictureTypesList->hasPictureType($assetInfo->getPictureType())
            && ($assetEvent->getAsset() instanceof Image || $assetEvent->getAsset() instanceof Unknown)
        ) {
            // add some metadata
            $assetEvent->getAsset()->addMetadata('title', 'Input', $assetEvent->getAsset()->getFilename());
            $assetEvent->getAsset()->addMetadata('position', 'Input', $assetInfo->getPicturePosition());
            foreach ($this->pictureTypesList->getPictureTypeConfig($assetInfo->getPictureType())->getMetaData() as $metaDataName => $metaDataValue) {
                $assetEvent->getAsset()->addMetadata($metaDataName, 'Input', $metaDataValue);
            }
        }
    }
}

==> lifestyle-pimcore-plugin-assign-product-images-1.5.3-56a493.zip: src/Lifestyle/Pimcore/AssignProductImagesBundle/EventListener/AddAssetListener.php <==
<?php

/**
 * Lifestyle Webconsulting GmbH
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @author      r.stetter
 * @copyright   2019 Lifestyle Webconsulting GmbH
 * @link        http://www.life-style.de
 */

namespace Lifestyle\Pimcore\AssignProductImagesBundle\EventListener;

use Lifestyle\Pimcore\AssignProductImagesBundle\Configuration\ActiveConfig;
use Lifestyle\Pimcore\AssignProductImagesBundle\Configuration\PictureTypesList;
use Lifestyle\Pimcore\AssignProductImagesBundle\Events\AssignProductImagesEvents;
use Lifestyle\Pimcore\AssignProductImagesBundle\Model\AssetInfo;
use Lifestyle\Pimcore\AssignProductImagesBundle\Services\AssetTypeHandler\AssetTypeHandlerFactory;
use Lifestyle\Pimcore\AssignProductImagesBundle\Services\AssetTypeHandler\AssetTypeHandlerNotDefinedException;
use Pimcore\Event\Model\AssetEvent;
use Pimcore\Model\Asset;
use Pimcore\Model\Asset\Image;
use Pimcore\Model\Asset\Unknown;
use Pimcore\Model\Factory as ModelFactory;
use Pimcore\Tests\Helper\Model;
use Symfony\Component\EventDispatcher\EventDispatcher;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

/**
 * Class AddAssetListener
 *
 * @package Lifestyle\Pimcore\AssignProductImagesBundle\EventListener
 */
class AddAssetListener
{
    /**
     * @var AssetTypeHandlerFactory
     */
    protected $assetTypeHandlerFactory;
    /**
     * @var EventDispatcher
     */
    protected $eventDispatcher;
    /**
     * @var PictureTypesList
     */
    protected $pictureTypesList;
    /**
     * @var ModelFactory;
     */
    protected $modelFactory;
    /**
     * @var bool
     */
    protected $active = false;

    /**
     * AddAssetListener constructor.
     *
     * @param AssetTypeHandlerFactory $assetTypeHandlerFactory
     * @param EventDispatcherInterface $eventDispatcher
     * @param PictureTypesList $pictureTypesList
     * @param ModelFactory $modelFactory
     * @param ActiveConfig $activeConfig
     */
    public function __construct(
        AssetTypeHandlerFactory $assetTypeHandlerFactory,
        EventDispatcherInterface $eventDispatcher,
        PictureTypesList $pictureTypesList,
        ModelFactory $modelFactory,
        ActiveConfig $activeConfig
    ) {
        $this->assetTypeHandlerFactory = $assetTypeHandlerFactory;
        $this->eventDispatcher = $eventDispatcher;
        $this->pictureTypesList = $pictureTypesList;
        $this->modelFactory = $modelFactory;
        $this->active = $activeConfig->isActive();
    }

    /**
     * @param AssetEvent $assetEvent
     * @throws AssetTypeHandlerNotDefinedException
     */
    public function onAssetUpdated(AssetEvent $assetEvent)
    {
        if (false === $this->active) {
            return;
        }

        $assetInfo = new AssetInfo($assetEvent->getAsset());

        if (
            $this->pictureTypesList->hasPictureType($assetInfo->getPictureType())
            && ($assetEvent->getAsset() instanceof Image || $assetEvent->getAsset() instanceof Unknown)
        ) {
            $pictureTypeConfig = $this->pictureTypesList->getPictureTypeConfig($assetInfo->getPictureType());

            if (
                false === stripos(
                    $assetEvent->getAsset()->getFullPath(),
                    '/' . $pictureTypeConfig->getProcessingPath()
                )
            ) {
                $success = $this->assetTypeHandlerFactory->getByType($pictureTypeConfig->getType())->process(
                    $assetEvent,
                    $pictureTypeConfig
                );

                if (true === $success) {
                    // dispatch post assign event
                    $this->eventDispatcher->dispatch($assetEvent, AssignProductImagesEvents::POST_ASSIGN);
                }
            }
        }
    }

    /**
     * @param AssetEvent $assetEvent
     */
    public function onBeforeAssetUpdated(AssetEvent $assetEvent)
    {
        if (false === $this->active) {
            return;
        }

        $assetInfo = new AssetInfo($assetEvent->getAsset());

        if (
            $this->pictureTypesList->hasPictureType($assetInfo->getPictureType())
            && ($assetEvent->getAsset() instanceof Image || $assetEvent->getAsset() instanceof Unknown)
        ) {
            // add some metadata
            $assetEvent->getAsset()->addMetadata('title', 'Input', $assetEvent->getAsset()->getFilename());
            $assetEvent->getAsset()->addMetadata('position', 'Input', $assetInfo->getPicturePosition());

            $metadata = $this->pictureTypesList->getPictureTypeConfig($assetInfo->getPictureType())->getMetaData();
            foreach ($metadata as $metaDataName => $metaDataValue) {
                $assetEvent->getAsset()->addMetadata($metaDataName, 'Input', $metaDataValue);
            }
        }
    }
}
